@@ -1,11 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
+#include "kpimtextedit_private_export.h"
+#include "texteditfindbarbase.h"
 #include <QTextDocument>
 #include <QWidget>
 
@@ -14,21 +16,21 @@ class QLineEdit;
 class QPushButton;
 namespace KPIMTextEdit
 {
-class TextFindWidget : public QWidget
+class KPIMTEXTEDIT_TESTS_EXPORT TextFindWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit TextFindWidget(QWidget *parent = nullptr);
     ~TextFindWidget() override;
 
-    Q_REQUIRED_RESULT QTextDocument::FindFlags searchOptions() const;
+    Q_REQUIRED_RESULT TextEditFindBarBase::FindFlags searchOptions() const;
 
     QLineEdit *searchLineEdit() const;
 
     void setFoundMatch(bool match);
 
     Q_REQUIRED_RESULT bool isRegularExpression() const;
-    Q_REQUIRED_RESULT QRegularExpression searchRegExp() const;
+    Q_REQUIRED_RESULT QRegularExpression searchRegularExpression() const;
 
     Q_REQUIRED_RESULT QString searchText() const;
 
@@ -44,16 +46,18 @@ Q_SIGNALS:
     void searchStringEmpty(bool);
 
 private:
-    QLineEdit *mSearch = nullptr;
+    void slotRegularExpressionChanged(bool b);
+    QLineEdit *const mSearch;
     QAction *mCaseSensitiveAct = nullptr;
     QAction *mWholeWordAct = nullptr;
-    QAction *mRegExpAct = nullptr;
+    QAction *mRegularExpressionAct = nullptr;
+    QAction *mRespectDiacriticAct = nullptr;
 
-    QPushButton *mFindPrevBtn = nullptr;
-    QPushButton *mFindNextBtn = nullptr;
+    QPushButton *const mFindPrevBtn;
+    QPushButton *const mFindNextBtn;
 };
 
-class TextReplaceWidget : public QWidget
+class KPIMTEXTEDIT_TESTS_EXPORT TextReplaceWidget : public QWidget
 {
     Q_OBJECT
 public:
@@ -70,8 +74,8 @@ Q_SIGNALS:
     void replaceAllText();
 
 private:
-    QLineEdit *mReplace = nullptr;
-    QPushButton *mReplaceBtn = nullptr;
-    QPushButton *mReplaceAllBtn = nullptr;
+    QLineEdit *const mReplace;
+    QPushButton *const mReplaceBtn;
+    QPushButton *const mReplaceAllBtn;
 };
 }
